@@ -1,8 +1,8 @@
 \dontrun{
 
-##############################################################################################
+######################################################################
 ## Estimate parameter values from experimental data
-##############################################################################################
+######################################################################
 
 library(deSolve)
 
@@ -22,7 +22,8 @@ grad <- attr(f_s, "grad")
 forcings <- attr(f_s, "forcings")
 
 # Generate ODE function
-func <- funC(f = c(f, f_s, chi, grad), forcings = forcings, fcontrol = "nospline")
+func <- funC(f = c(f, f_s, chi, grad), forcings = forcings, 
+             fcontrol = "nospline")
 
 # Initialize times, states, parameters
 times <- seq(0, 15, by = .1)
@@ -35,7 +36,9 @@ pars <- c(build_O3 = .2, decay_O3 = .1)
 # Initialize forcings (the data)
 data(oxygenData)
 forcData <- data.frame(time = oxygenData[,1],
-                       name = rep(colnames(oxygenData[,-1]), each=dim(oxygenData)[1]),
+                       name = rep(
+                         colnames(oxygenData[,-1]), 
+                         each=dim(oxygenData)[1]),
                        value = as.vector(oxygenData[,-1]))
 forc <- setForcings(func, forcData)
 
@@ -52,10 +55,12 @@ M2 <- out[,names(grad)]
 tD <- oxygenData[,1]
 M1D <- oxygenData[,2:4]
 
-matplot(t, M1, type="l", lty=1, col=1:3, xlab="time", ylab="value", main="states")
+matplot(t, M1, type="l", lty=1, col=1:3, 
+        xlab="time", ylab="value", main="states")
 matplot(tD, M1D, type="b", lty=2, col=1:3, pch=4, add=TRUE)
 legend("topright", legend = names(f), lty=1, col=1:3)
-matplot(t, M2, type="l", lty=1, col=1:5, xlab="time", ylab="value", main="gradient")
+matplot(t, M2, type="l", lty=1, col=1:5, 
+        xlab="time", ylab="value", main="gradient")
 legend("topleft", legend = names(grad), lty=1, col=1:5)
 
 # Define objective function
@@ -65,7 +70,8 @@ obj <- function(p) {
 	      forcings = forc, method="lsodes")
   
   value <- as.vector(tail(out, 1)[,"chi"])
-  gradient <- as.vector(tail(out, 1)[,paste("chi", names(p), sep=".")])
+  gradient <- as.vector(
+    tail(out, 1)[,paste("chi", names(p), sep=".")])
   hessian <- gradient%*%t(gradient)
   
   return(list(value = value, gradient = gradient, hessian = hessian))
@@ -92,10 +98,12 @@ M2 <- prediction[,names(grad)]
 tD <- oxygenData[,1]
 M1D <- oxygenData[,2:4]
 
-matplot(t, M1, type="l", lty=1, col=1:3, xlab="time", ylab="value", main="states")
+matplot(t, M1, type="l", lty=1, col=1:3, 
+        xlab="time", ylab="value", main="states")
 matplot(tD, M1D, type="b", lty=2, col=1:3, pch=4, add=TRUE)
 legend("topright", legend = names(f), lty=1, col=1:3)
-matplot(t, M2, type="l", lty=1, col=1:5, xlab="time", ylab="value", main="gradient")
+matplot(t, M2, type="l", lty=1, col=1:5, 
+        xlab="time", ylab="value", main="gradient")
 legend("topleft", legend = names(grad), lty=1, col=1:5)
 
 }
