@@ -1,8 +1,8 @@
 \dontrun{
 
-##############################################################################################
+######################################################################
 ## Solve an optimal control problem:
-##############################################################################################
+######################################################################
 
 library(bvpSolve)
 
@@ -30,12 +30,14 @@ boundary <- data.frame(
 pars <- c(build_O3 = .2, decay_O3 = .1, eps = 1)
 
 # Generate ODE function
-func <- funC(f = f_tot, forcings = forcings, jacobian = "full", boundary = boundary)
+func <- funC(f = f_tot, forcings = forcings, 
+             jacobian = "full", boundary = boundary)
 
 # Initialize forcings (the objective)
 forcData <- data.frame(time = times,
                        name = rep(forcings, each=length(times)),
-                       value = rep(c(0.5, 0, 1, 1), each=length(times)))
+                       value = rep(
+                         c(0.5, 0, 1, 1), each=length(times)))
 forc <- setForcings(func, forcData)
 
 # Solve BVP
@@ -45,13 +47,16 @@ out <- bvptwpC(x = times, func = func, parms = pars, forcings = forc)
 par(mfcol=c(1,2))
 t <- out[,1]
 M1 <- out[,2:4]
-M2 <- with(list(uD = 0, O3 = out[,2], adjO3 = out[,5], eps = 1, weightuD = 1), 
+M2 <- with(list(uD = 0, O3 = out[,2], 
+                adjO3 = out[,5], eps = 1, weightuD = 1), 
            eval(parse(text=inputs)))
 
-matplot(t, M1, type="l", lty=1, col=1:3, xlab="time", ylab="value", main="states")
+matplot(t, M1, type="l", lty=1, col=1:3, 
+        xlab="time", ylab="value", main="states")
 abline(h = .5, lty=2)
 legend("topright", legend = names(f), lty=1, col=1:3)
-matplot(t, M2, type="l", lty=1, col=1, xlab="time", ylab="value", main="input u")
+matplot(t, M2, type="l", lty=1, col=1, 
+        xlab="time", ylab="value", main="input u")
 abline(h = 0, lty=2)
 
 }
